@@ -12,7 +12,7 @@
  *  PCI to PCI Bridge Specification
  *  PCI System Design Guide
  *
- * $Id: pci.h,v 1.11 2007/07/26 06:12:29 ralf Exp $
+ * $Id$
  */
 
 #ifndef _RTEMS_PCI_H
@@ -1127,17 +1127,17 @@ typedef struct  {
 #define PCIB_ERR_DEVNOTFOUND   (-5)  /* Device not found */
 #define PCIB_ERR_BADREG        (-6)  /* Bad register number */
 
-extern int pci_initialize();
+extern int pci_initialize(void);
 
 typedef struct {
   volatile unsigned char*            pci_config_addr;
   volatile unsigned char*            pci_config_data;
   const pci_config_access_functions* pci_functions;
-} pci_config;
+} rtems_pci_config_t;
 
-extern pci_config BSP_pci_configuration;
+extern rtems_pci_config_t BSP_pci_configuration;
 
-extern inline int
+static inline int
 pci_read_config_byte(
   unsigned char bus,
   unsigned char slot,
@@ -1149,7 +1149,7 @@ pci_read_config_byte(
             bus, slot, function, where, val);
 }
 
-extern inline int
+static inline int
 pci_read_config_word(
   unsigned char bus,
   unsigned char slot,
@@ -1161,7 +1161,7 @@ pci_read_config_word(
              bus, slot, function, where, val);
 }
 
-extern inline int
+static inline int
 pci_read_config_dword(
   unsigned char bus,
   unsigned char slot,
@@ -1172,19 +1172,19 @@ pci_read_config_dword(
   return BSP_pci_configuration.pci_functions->read_config_dword(bus, slot, function, where, val);
 }
 
-extern inline int
+static inline int
 pci_write_config_byte(
-  unsigned char bus, 
-  unsigned char slot, 
+  unsigned char bus,
+  unsigned char slot,
   unsigned char function,
-  unsigned char where, 
+  unsigned char where,
   uint8_t       val)
 {
   return BSP_pci_configuration.pci_functions->write_config_byte(
              bus, slot, function, where, val);
 }
 
-extern inline int
+static inline int
 pci_write_config_word(
   unsigned char bus,
   unsigned char slot,
@@ -1196,7 +1196,7 @@ pci_write_config_word(
               bus, slot, function, where, val);
 }
 
-extern inline int
+static inline int
 pci_write_config_dword(
   unsigned char bus,
   unsigned char slot,
@@ -1227,7 +1227,7 @@ pci_find_device(
 /*
  * Return the number of PCI busses in the system
  */
-extern unsigned char pci_bus_count();
+extern unsigned char pci_bus_count(void);
 
 #ifdef __cplusplus
 }
